@@ -8,7 +8,7 @@
 
 #include <stdio.h>
 
-//#include <QtGui/QApplication>  // So we get qApp with Qt<=4.2
+#include <QtGui/QApplication>  // So we get qApp with Qt<=4.2
 #include <QCoreApplication>
 
 #include <sy/sycmdswitch.h>
